# encoding : UTF-8 
#
# gsf-boite.rb - Génération des boîtes
#
# Edouard.Thiel@lif.univ-mrs.fr - 21/11/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require './gsf-doc-xml'
require './gsf-base-docs'

class Boite

  # Accesseurs
  #
  attr_accessor :base


  # Initialisation
  #
  def initialize(base)
    @base = base
  end


  # Ecrit des boîtes à droite dans le fichier f
  #
  def gen_html_boite_d(f, elt_boite, elt_page, elt_ue)

    return if elt_boite == nil

    titre   = DocXml.get_text(elt_boite, 'titre')
    legende = DocXml.get_text(elt_boite, 'legende')

    f.print <<-FINTEXTE
  <div class="boite-droite">
    <div class="titre">
      #{titre}
    </div>
    FINTEXTE

    f.puts "    <p>#{legende}</p>" if legende != ""

    elt_boite.elements.each('eliste') do |elt_eliste|

      f.puts "    <ul>"

      elt_eliste.elements.each('eli') do |elt_eli|

        type = DocXml.get_attr(elt_eli, 'type')

        case type
          when ""
            gen_html_eliste_item(f, elt_eli)
          when "lien-sections"
            gen_html_lien_sections(f, elt_page)
          when "lien-parcours"
            gen_html_lien_parcours(f, elt_page)
          when "ident-formation"
            gen_html_ident_formation(f)
          when "informations-ue"
            gen_html_informations_ue(f, elt_ue)
          when "apparitions-ue"
            gen_html_apparitions_ue(f, elt_ue)
          when "prec-suiv-ue"
            gen_html_prec_suiv_ue(f, elt_ue)
          when "resp"
            gen_html_responsable(f, elt_eli)
          when "responsables-ue"
            gen_html_responsables_ue(f, elt_ue)
          when "responsables-page"
            gen_html_responsables_page(f, elt_page)
          else
            $stderr.puts "** Erreur: dans boîte '#{titre}': type '#{type}' inconnu"
        end

      end
      f.puts "    </ul>"
    end

    f.puts"  </div> <!-- boite-droite -->\n\n"
  end


  # Génère un item de eliste
  #
  def gen_html_eliste_item(f, elt_eli)

    href = DocXml.get_attr(elt_eli, 'href')

    f.print "      <li>"
    f.print "<a href=\"#{href}\">" unless href == ""
    f.print elt_eli.text unless elt_eli.text == nil or
                                elt_eli.text.strip.empty?
    f.print "</a>" unless href == ""
    f.puts "</li>"
  end


  # Génère les liens sur les sections
  #
  def gen_html_lien_sections(f, elt_page)

    return if elt_page == nil

    elt_page.elements.each('section') do |elt_section|

      id   = DocXml.get_attr(elt_section, 'id')
      titre = DocXml.get_text(elt_section, 'titre')

      f.puts "      <li><a href=\"\##{id}\">#{titre}</a></li>"
    end
  end


  # Génère les liens sur les parcours
  #
  def gen_html_lien_parcours(f, elt_page)

    return if elt_page == nil

    nom_page = DocXml.get_attr(elt_page, 'dest')

    @base.x_par.elements.each('liste-parcours/parcours') do |elt_parcours|

      id    = DocXml.get_attr(elt_parcours, 'id')
      href  = DocXml.get_attr(elt_parcours, 'href')
      titre = DocXml.get_text(elt_parcours, 'titre')

      if nom_page == href
           f.print "      <li class = \"selected\">"
      else f.print "      <li>"
      end
      f.print "<a href=\"#{href}\">#{titre}</a>"
      f.puts "</li>"
    end
  end


  # Génère l'identité de la formation
  #
  def gen_html_ident_formation(f)

    elt_forma = @base.x_div.get_unique_element('liste-divers/formation')

    diplome  = DocXml.get_text(elt_forma, 'diplome')
    domaine  = DocXml.get_text(elt_forma, 'domaine')
    mention  = DocXml.get_text(elt_forma, 'mention')
    parcours = DocXml.get_text(elt_forma, 'parcours')

    f.puts "      <li>Diplôme&nbsp;: #{diplome}</li>" unless diplome == nil
    f.puts "      <li>Domaine&nbsp;: #{domaine}</li>" unless domaine == nil
    f.puts "      <li>Mention&nbsp;: #{mention}</li>" unless mention == nil
    f.puts "      <li>Parcours&nbsp;: #{parcours}</li>" unless parcours == nil
  end


  # Génère les informations d'une UE
  #
  def gen_html_informations_ue(f, elt_ue)

    return if elt_ue == nil

    code = DocXml.get_text(elt_ue, 'code')
    ects = DocXml.get_text(elt_ue, 'ects')
    natu = DocXml.get_text(elt_ue, 'nature')
    
    f.puts "      <li>Code&nbsp;: #{code}</li>"
    f.puts "      <li>Crédits&nbsp;: #{ects}</li>"
    f.puts "      <li>Nature&nbsp;: #{natu}</li>"

    elt_h_etud = elt_ue.elements['h-etud']
    if elt_h_etud != nil
      h_cm  = DocXml.get_text(elt_h_etud, 'cm')
      h_td  = DocXml.get_text(elt_h_etud, 'td')
      h_tp  = DocXml.get_text(elt_h_etud, 'tp')
      h_pro = DocXml.get_text(elt_h_etud, 'pro')

      if h_cm != "" or h_td != "" or h_tp != ""
        cm = (h_cm == "") ? "0" : h_cm
        td = (h_td == "") ? "0" : h_td
        tp = (h_tp == "") ? "0" : h_tp
        f.puts "      <li>CM/TD/TP&nbsp;: #{cm}/#{td}/#{tp} h</li>"
      end

      if h_pro != ""
        f.puts "      <li>Volume&nbsp;: #{h_pro}</li>"
      end
    end
  end


  # Génère les apparitions d'une UE
  #
  def gen_html_apparitions_ue(f, elt_ue)

    return if elt_ue == nil

    ue_id = DocXml.get_attr(elt_ue, 'id')
    apparu = false

    @base.x_sem.elements.each('liste-semestres/semestre') do |elt_sem|

      nom_sem = DocXml.get_text(elt_sem, 'surnom')

      elt_sem.elements.each('groupe') do |elt_grp|

        nom2 = DocXml.get_attr(elt_grp, 'surnom')

        elt_grp.elements.each("matiere[@ref='#{ue_id}']") do |elt_mat|

          f.puts "      <li>#{nom2 != "" ? nom2 : nom_sem}</li>"
          apparu = true
          break
        end

      end
    end

    if !apparu
      $stderr.puts "** Warning: UE #{ue_id} non trouvée dans les semestres"
    end
  end


  # Génère le lien vers l'UE précédente et suivante
  #
  def gen_html_prec_suiv_ue(f, elt_ue)

    return if elt_ue == nil

    ue_prec = elt_ue.previous_element
    ue_suiv = elt_ue.next_element

    code_prec = DocXml.get_text(ue_prec, 'code')
    code_suiv = DocXml.get_text(ue_suiv, 'code')

    lien_prec = code_prec == "" ? 
      "précédente" : "<a href=\"ue-#{code_prec}.html\">précédente</a>"
    lien_suiv = code_suiv == "" ? 
      "suivante" : "<a href=\"ue-#{code_suiv}.html\">suivante</a>"

    f.puts "      <li>UE #{lien_prec}, #{lien_suiv}</li>"
  end


  # Génère un responsable
  #
  def gen_html_responsable(f, elt_eli)

    nom   = DocXml.get_attr(elt_eli, 'nom')
    role  = DocXml.get_attr(elt_eli, 'role')
    web   = DocXml.get_attr(elt_eli, 'web')

    gen_html_resp_par_infos(f, nom, role, web)   
  end


  # Génère les responsables de l'UE
  #
  def gen_html_responsables_ue(f, elt_ue)

    return if elt_ue == nil

    ref_ue = DocXml.get_attr(elt_ue, 'id')
    
    @base.x_resp.elements.each(
        "liste-responsables/resp[@ref-ue='#{ref_ue}']") do |elt_resp|

      ref_ens = DocXml.get_attr(elt_resp, 'ref-ens')
      role = DocXml.get_attr(elt_resp, 'role')

      gen_html_resp_par_ref(f, ref_ens, role)
    end
  end


  # Génère les responsables relatifs à la page
  #
  def gen_html_responsables_page(f, elt_page)

    return if elt_page == nil

    ref_page = DocXml.get_attr(elt_page, 'id')

    @base.x_resp.elements.each(
        "liste-responsables/resp[@ref-page='#{ref_page}']") do |elt_resp|

      ref_ens = DocXml.get_attr(elt_resp, 'ref-ens')
      role = DocXml.get_attr(elt_resp, 'role')

      gen_html_resp_par_ref(f, ref_ens, role)
    end
  end


  # Génère une ligne indiquant le responsable à partir de ref_ens
  # Le lien renvoie vers l'annuaire
  #
  def gen_html_resp_par_ref(f, ref_ens, role)

    return if ref_ens == ""

    elt_ens = @base.x_ens.get_unique_element(
        "liste-enseignants/ens[@id='#{ref_ens}']")
    if elt_ens == nil
      $stderr.puts "** Erreur: enseignant #{ref_ens} non trouvé"
      return
    end

    elt_annu = @base.x_div.get_unique_element('liste-divers/annuaire')
    href_annu = DocXml.get_attr(elt_annu, 'href')
    if href_annu == ""
      $stderr.puts "** Erreur: href annuaire non trouvé"
      return
    end

    nom = DocXml.get_attr(elt_ens, 'nom')
    id = DocXml.get_attr(elt_ens, 'id')
    web = "#{href_annu}\##{id}"

    gen_html_resp_par_infos(f, nom, role, web)
  end


  # Génère une ligne indiquant le responsable
  #
  def gen_html_resp_par_infos(f, nom, role, web)

    f.print "      <li>"
    f.print "<a href=\"#{web}\">" if web != ""
    f.print nom
    f.print "</a>" if web != ""
    f.print " (#{role})" if role != ""
    f.puts "</li>"
  end


end  # Fin classe

