# encoding : UTF-8 
#
# gsf-categories.rb - Génération de la liste des UEs par categorie
#
# Edouard.Thiel@lif.univ-mrs.fr - 10/10/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require './gsf-doc-xml'
require './gsf-base-docs'


class Categories

  # Accesseurs
  #
  attr_accessor :base


  # Initialisation
  #
  def initialize(base)
    @base = base
  end


  #----------------------------------------------------------------------------

  # Génère les categories
  #
  def gen_html_categories(f)

    if @base == nil || @base.x_cat == nil
      $stderr.puts "** Erreur: gen_html_categories: base XML non définie"
      return
    end

    @base.x_cat.elements.each('liste-categories/categorie') do |elt_cat|
      gen_html_categorie_elt_cat(f, elt_cat)
    end
  end


  # Génère une catégorie
  #
  def gen_html_categorie_elt_cat(f, elt_cat)

    return if elt_cat == nil

    ref_cat   = DocXml.get_attr(elt_cat, 'id')
    titre_cat = DocXml.get_text(elt_cat, 'titre')
    f.puts "  <h3 id=\"#{ref_cat}\">#{titre_cat}</h3>\n\n"

    legende_cat = DocXml.get_text(elt_cat, 'legende')
    f.puts "  <p>#{legende_cat}</p>\n\n" if legende_cat != ""
    f.puts "  <ul>"

    elt_cat.elements.each('matiere') do |elt_mat|
      gen_html_matiere(f, elt_mat, ref_cat)
    end

    f.puts "  </ul>\n\n"
  end


  # Génère le contenu des enseignements d'une matiere
  #
  def gen_html_matiere(f, elt_mat, ref_cat)

    ref_mat = DocXml.get_attr(elt_mat, 'ref')
    code    = DocXml.get_attr(elt_mat, 'code')
    titre   = DocXml.get_attr(elt_mat, 'titre')
    href    = DocXml.get_attr(elt_mat, 'href')
    texte   = DocXml.get_attr(elt_mat, 'texte')
    ects    = DocXml.get_attr(elt_mat, 'ects')
    orig    = DocXml.get_attr(elt_mat, 'orig')  # inutilisé
    horig   = DocXml.get_attr(elt_mat, 'horig') # inutilisé

    ue = @base.x_ues.get_element('ue', 'id', ref_mat)
    if ue != nil
      if code  == "" then code  = DocXml.get_text(ue, 'code') ; end
      if titre == "" then titre = DocXml.get_text(ue, 'titre') ; end
      if href  == "" then href  = "ue-#{code}.html" ; end
      if ects  == "" then ects  = DocXml.get_text(ue, 'ects') ; end
    end

    if code == "" and titre == "" and texte == ""
      $stderr.puts "** Erreur dans catégorie '#{ref_cat}' : matiere '#{ref_mat}' non définie"
      f.puts "      <li><b>** MATIERE NON DEFINIE !!</b></li>"
      return
    end

    f.print "      <li>"
    f.print "#{code}&nbsp;: " if code != ""
    f.print "<a href=\"#{href}\">" if href != ""
    f.print titre
    f.print "</a>" if href != ""
    f.print " #{texte} (#{ects} crédits)"
    f.puts "</li>"
  end


end  # Fin classe


