# encoding : UTF-8 
#
# gsf-doc-xml.rb - Gestion d'un document xml
#
# Edouard.Thiel@lif.univ-mrs.fr - 10/10/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require 'rexml/document'


class DocXml < REXML::Document

  # Accesseurs
  #
  attr_accessor :doc


  # Initialisation
  #
  def initialize
    @doc = nil
  end

 
  # Lecture du document XML, avec inclusions éventuelles de la forme
  #     <inclure src="">
  def lire_xml(src)
    begin
      puts "Lecture de #{src} ..."
      file = File.new(src)
      @doc = REXML::Document.new(file)
      traiter_inclusions(@doc, 1)
    rescue => ex
      $stderr.puts "** Erreur: lire_xml : #{ex.message}"
      exit 1
    end
  end


  # Effectuer les inclusions de documents XML de la forme
  #     <inclure src="">
  def traiter_inclusions(doc, niveau)

    if (niveau > 32)
      raise "inclusion en boucle détectée"
    end

    doc.elements.each("//inclure") do |elt|
      src = DocXml.get_attr(elt, 'src')
      puts "#{'  '*niveau}Inclusion de #{src} ..."
      file = File.new(src)
      subdoc = REXML::Document.new(file)
      traiter_inclusions(subdoc, niveau+1)
      elt.replace_with(subdoc.root)
    end
  end


  # Raccourcis
  #
  def elements
    @doc.elements
  end


  # Renvoie un élément spécifié par un chemin et un couple (clef, valeur)
  # sinon nil
  #
  def get_element(chemin, clef, valeur)
    chemin == nil || clef == nil || valeur == nil ? nil :
      @doc.root.elements["#{chemin}[@#{clef}='#{valeur}']"]
  end


  # Renvoie le premier élément spécifié par un chemin, et affiche
  # une erreur si il n'est pas unique
  #
  def get_unique_element(chemin)

    if chemin == nil
      $stderr.puts "** Erreur: get_unique_element: chemin vide"
      return nil
    end

    premier_elt = nil
    @doc.elements.each(chemin) do |elt|

      if premier_elt == nil
        premier_elt = elt
      else
        $stderr.puts "** Erreur: get_unique_element: élément '#{chemin}' non unique"
        break
      end
    end
    
    return premier_elt
  end


  # Méthodes de classe : commencent par self

  # Renvoie le texte du sous-élément de clé id, sinon ""
  #
  def self.get_text(e, id)
    if e == nil || id == nil || e.elements == nil || e.elements[id] == nil
      return ""
    end
    s = e.elements[id].text
    return s == nil ? "" : s
  end


  # Renvoie l'attribut de clé id, sinon ""
  #
  def self.get_attr(e, id)
    e == nil || id == nil || e.attributes == nil ||
      e.attributes[id] == nil ? "" : e.attributes[id]
  end

end  # Fin classe


