# encoding : UTF-8 
#
# gsf-onglets.rb - Génération des onglets
#
# Edouard.Thiel@lif.univ-mrs.fr - 21/11/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require './gsf-doc-xml'
require './gsf-base-docs'


class Onglets

  # Accesseurs
  #
  attr_accessor :base


  # Initialisation
  #
  def initialize(base)
    @base = base
  end


  # Ecrit des onglets dans le fichier f
  #
  def gen_html_onglets(f, elt_onglet, nom_page)

    return if elt_onglet == nil

    f.print <<-FINTEXTE
<table class="onglets">
<tbody>
<tr>
    FINTEXTE

    elt_onglet.elements.each('elo') do |elt_elo|

      type = DocXml.get_attr(elt_elo, 'type')
      href = DocXml.get_attr(elt_elo, 'href')

      case type
        when ""
          gen_html_onglet(f, false, href, elt_elo.text)
        when "select"
          gen_html_onglet(f, true, href, elt_elo.text)
        when "liste-communs"
          gen_html_onglets_communs(f, nom_page)
        when "nouvelle-ligne"
          gen_html_nouvelle_ligne(f)
        else
          $stderr.puts "** Erreur: dans onglets, type '#{type}' inconnu"
          f.puts "  <td>???</td>"
      end
            
    end

    f.print <<-FINTEXTE
</tr>
</tbody>
</table> <!-- onglets -->
    FINTEXTE
  end


  # Génère les onglets communs
  #
  def gen_html_onglets_communs(f, nom_page)

    elt_onglets = @base.x_div.get_unique_element('liste-divers/onglets')
    return if elt_onglets == nil

    elt_onglets.elements.each('elo') do |elt_elo|

      type = DocXml.get_attr(elt_elo, 'type')
      href = DocXml.get_attr(elt_elo, 'href')

      case type
        when ""
          gen_html_onglet(f, nom_page == href, href, elt_elo.text)
        when "nouvelle-ligne"
          gen_html_nouvelle_ligne(f)
        else
          $stderr.puts "** Erreur: dans onglets, type '#{type}' non supporté"
          f.puts "  <td>???</td>"
      end
    end
  end


  # Génère une nouvelle ligne d'onglets
  #
  def gen_html_nouvelle_ligne(f)
    f.print <<-FINTEXTE
</tr>
</tbody>
</table> <!-- onglets -->

<table class="onglets">  <!-- Nouvelle ligne d'onglets -->
<tbody>
<tr>
    FINTEXTE
  end


  # Génère un onglet sélectionnable
  #
  def gen_html_onglet(f, selected, href, text)

    if selected
         f.print "  <td class=\"selected\">"
    else f.print "  <td>"
    end

    f.print "<a href=\"#{href}\">" unless href == ""
    f.print text unless text == nil or text.strip.empty?
    f.print "</a>" unless href == ""
    f.puts "</td>"
  end


end  # Fin classe

