# encoding : UTF-8 
#
# gsf-page-html.rb - Génération d'une page html
#
# Edouard.Thiel@lif.univ-mrs.fr - 10/10/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


class PageHtml

  # Accesseurs
  #
  attr_accessor :titre, :styles, :scripts


  # Initialisation
  #
  def initialize
    @titre   = "Sans titre"
    @styles  = []
    @scripts = []
  end


  # Ecrit l'encodage dans le fichier f
  #
  def ecrire_encodage(f)
    f.print <<-FINTEXTE
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

    FINTEXTE
  end


  # Ecrit l'entete dans le fichier f
  #
  def ecrire_entete(f)
    f.print <<-FINTEXTE
<head>
<title>#{@titre}</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta http-equiv="Cache-Control" content="no-cache" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<link type="image/x-icon" href="images/favicon-amu.png" rel="icon" />
    FINTEXTE

    @styles.each { |name|
      f.puts %Q{<link rel="stylesheet" type="text/css" href="#{name}" />}
    }
    @scripts.each { |name|
      f.puts %Q{<script language="JavaScript" type="text/javascript" src="#{name}"></script>}
    }

    f.print <<-FINTEXTE
</head>

    FINTEXTE
  end


  # Ecrit le début du corps dans le fichier f
  #
  def ecrire_debut_corps(f)
    f.print <<-FINTEXTE
<body>

    FINTEXTE
  end


  # Ecrit le corps dans le fichier f
  #
  def ecrire_corps(f)
    f.print <<-FINTEXTE
    <h1>Sans titre</h1>

    FINTEXTE
  end


  # Ecrit le pied de page dans le fichier f
  #
  def ecrire_pied(f)
    f.print <<-FINTEXTE
<div>
  Page en
  <a href="http://validator.w3.org/check?uri=referer">XHTML 1.0 strict</a> et
  <a href="http://jigsaw.w3.org/css-validator/check/referer">CSS 2.1</a> &nbsp;-&nbsp;
  #{Time.now.strftime("%d %b %Y")}
</div>

    FINTEXTE
  end


  # Ecrit la fin du corps dans le fichier f
  #
  def ecrire_fin_corps(f)
    f.print <<-FINTEXTE
</body>

    FINTEXTE
  end


  # Ecrit la fin de la page dans le fichier f
  #
  def ecrire_fin_page(f)
    f.print <<-FINTEXTE
</html>

    FINTEXTE
  end


  # Génère une page Html
  #
  def generer_page(dest)
    begin
      puts "Génération de #{dest} ..."
      f = File.new(dest, "w")

      ecrire_encodage(f)
      ecrire_entete(f)
      ecrire_debut_corps(f)
      ecrire_corps(f)
      ecrire_pied(f)
      ecrire_fin_corps(f)
      ecrire_fin_page(f)
    rescue => ex
      $stderr.puts "** Erreur: generer_page: #{ex.message}"
      exit 1
    ensure
      f.close unless f.nil?
    end
  end

end  # Fin classe


