# encoding : UTF-8 
#
# gsf-pages-site.rb - Génération des pages du site d'après leur description XML
#
# Edouard.Thiel@lif.univ-mrs.fr - 14/11/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.

require './gsf-page-html'
require './gsf-doc-xml'
require './gsf-base-docs'
require './gsf-onglets'
require './gsf-boite'
require './gsf-pied'
require './gsf-parcours'
require './gsf-categories'
require './gsf-responsables'


class PagesSite < PageHtml

  # Accesseurs
  #
  attr_accessor :base

  # Initialisation
  #
  def initialize(base)
    super()  # Appelle initialize de la classe mère

    @styles  = [ "style-gsf-15.css"]
    @scripts = []

    @base = base
    @elt_page = nil
  end


  #----------------------------------------------------------------------------

  # Génère toutes les pages d'un site de formation
  #
  def generer_site()

    if @base == nil || @base.x_pages == nil
      $stderr.puts "** Erreur: generer_site: base XML non définie"
      return
    end

    @base.x_pages.elements.each('liste-pages/page') do |elt_page|
      generer_site_elt_page(elt_page)
    end
  end


  # Génère une page d'un site, désignée par son id
  #
  def generer_site_ref_page(ref_page)

    if @base == nil || @base.x_pages == nil
      $stderr.puts "** Erreur: generer_site_ref_page: base XML non définie"
      return
    end

    elt_page = @base.x_pages.get_element('page', 'id', ref_page)
    if elt_page == nil
      $stderr.puts "** Erreur: generer_site_ref_page: ref '#{ref_page}' non trouvée"
      return
    end

    generer_site_elt_page(elt_page)
  end


  # Génère une page d'après son élément de page XML
  #
  def generer_site_elt_page(elt_page)

    if elt_page == nil
      $stderr.puts "** Erreur: generer_site_elt_page: page indéfinie"
      return
    end
 
    dest   = DocXml.get_attr(elt_page, 'dest')
    @titre = DocXml.get_attr(elt_page, 'htitre')
    @elt_page = elt_page

    generer_page(dest)
  end


  #----------------------------------------------------------------------------

  # Ecrit le début du corps dans le fichier f
  #
  def ecrire_debut_corps(f)

    f.print "<body>\n\n"

    elt = @base.x_div.get_unique_element('liste-divers/debut-pages')
    f.puts elt.text unless elt == nil
  end


  # Ecrit le corps dans le fichier f
  #
  def ecrire_corps(f)

    return if @elt_page == nil

    # Les onglets
    gen_html_onglets(f)

    f.puts "\n<div id=\"classeur1\">\n\n"

    # Les boîtes à droite
    gen_html_boites_d(f)

    # Le titre
    titre = DocXml.get_text(@elt_page, 'titre')
    f.puts "<h1>#{titre}</h1>\n\n"

    # La légende
    legende = DocXml.get_text(@elt_page, 'legende')
    f.puts "<p><i>#{legende}</i></p>\n\n" unless legende == ""

    # les sections
    gen_html_sections(f)

    f.puts "\n</div> <!-- classeur1 -->\n\n"
  end


  # Ecrit la fin du corps dans le fichier f
  #
  def ecrire_fin_corps(f)

    elt = @base.x_div.get_unique_element('liste-divers/fin-pages')
    f.puts elt.text unless elt == nil or elt.text == nil

    f.print "</body>\n\n"
  end


  #----------------------------------------------------------------------------

  # Génère les sections
  #
  def gen_html_sections(f)

    @elt_page.elements.each('section') do |elt_section|

      id   = DocXml.get_attr(elt_section, 'id')
      titre = DocXml.get_text(elt_section, 'titre')

      f.puts "  <h2 id=\"#{id}\">#{titre}</h2>\n\n"

      elt_section.elements.each('parag') do |elt_parag|

        type = DocXml.get_attr(elt_parag, 'type')
        ref  = DocXml.get_attr(elt_parag, 'ref')

        case type
          when ""

          when "contenu-parcours"
            parcours = Parcours.new(@base)
            parcours.gen_html_parcours(f, ref)

          when "categories-ues"
            categ = Categories.new(@base)
            categ.gen_html_categories(f)

          when "annuaire"
            resps = Responsables.new(@base)
            resps.gen_html_resps_alpha(f)

          else
            $stderr.puts "** Erreur: dans section '#{id}': parag type '#{type}' inconnu"
        end

        if elt_parag.text != nil
          f.puts "  <div>\n"
          f.puts elt_parag.text
          f.puts "  </div>\n\n"
        end

      end
    end
  end


  #----------------------------------------------------------------------------

  # Ecrit des onglets dans le fichier f
  #
  def gen_html_onglets(f)

    return if @elt_page == nil

    nom_page = DocXml.get_attr(@elt_page, 'dest')
    onglets = Onglets.new(@base)

    @elt_page.elements.each('onglets') do |elt_onglet|
      onglets.gen_html_onglets(f, elt_onglet, nom_page)
    end
  end


  # Ecrit des boîtes à droite dans le fichier f
  #
  def gen_html_boites_d(f)

    return if @elt_page == nil

    boite = Boite.new(@base)

    @elt_page.elements.each('boite-d') do |elt_boite|
      boite.gen_html_boite_d(f, elt_boite, @elt_page, nil)
    end
  end


  # Ecrit le pied de page dans le fichier f
  #
  def ecrire_pied(f)

    elt_sauv = @base.x_div.get_unique_element('liste-divers/sauvegarde')
    Pied.gen_html_pied(f, elt_sauv)
  end


end  # Fin classe



