# encoding : UTF-8 
#
# gsf-parcours.rb - Génération du contenu des enseignements d'un parcours
#
# Edouard.Thiel@lif.univ-mrs.fr - 10/10/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require './gsf-doc-xml'
require './gsf-base-docs'


class Parcours

  # Accesseurs
  #
  attr_accessor :base


  # Initialisation
  #
  def initialize(base)
    @base = base
  end


  #----------------------------------------------------------------------------

  # Génère le contenu des enseignements d'un parcours
  #
  def gen_html_parcours(f, ref_par)

    elt_par = @base.x_par.get_element('parcours', 'id', ref_par)
    return if elt_par == nil

    titre_par = DocXml.get_text(elt_par, 'titre')
    f.puts "  <!-- #{titre_par} -->\n\n"

    legende_par = DocXml.get_text(elt_par, 'legende')
    f.puts "  <p>#{legende_par}</p>\n\n" if legende_par != ""

    elt_par.elements.each('semestre') do |elt_sem|
      ref_sem = DocXml.get_attr(elt_sem, 'ref')
      gen_html_semestre(f, ref_sem)
    end
  end


  # Génère le contenu des enseignements d'un semestre
  #
  def gen_html_semestre(f, ref_sem)

    elt_sem = @base.x_sem.get_element('semestre', 'id', ref_sem)
    return if elt_sem == nil

    type_sem = DocXml.get_text(elt_sem, 'type')
    case type_sem
      when ''
        # valeur par défaut
      when 'invisible'
        return
      else
        $stderr.puts "** Erreur dans semestre '#{ref_sem}' : type de semestre '#{type_sem}' non défini"
      return
    end

    titre_sem = DocXml.get_text(elt_sem, 'titre')
    f.puts "  <h3 id=\"#{ref_sem}\">#{titre_sem}</h3>\n\n"

    legende_sem = DocXml.get_text(elt_sem, 'legende')
    f.puts "  <p>#{legende_sem}</p>\n\n" if legende_sem != ""
    f.puts "  <ul>"

    premier = true
    elt_sem.elements.each('groupe') do |elt_grp|
      if premier
      then premier = false
           f.puts "    <li>"
      else f.puts ""
           f.puts "    <li style=\"margin-top:10pt;\">"
      end

      gen_html_groupe(f, elt_grp, ref_sem)

      f.puts "    </li>"
    end

    f.puts "  </ul>\n\n"
  end


  # Génère le contenu des enseignements d'un groupe
  #
  def gen_html_groupe(f, elt_grp, ref_sem)

    type_grp = DocXml.get_attr(elt_grp, 'type')
    ects     = DocXml.get_attr(elt_grp, 'ects')
    texte    = DocXml.get_attr(elt_grp, 'texte')

    case type_grp

      when 'obligatoire'
        f.puts "      <i>Unités obligatoires #{texte} (#{ects}&nbsp;crédits)</i>"

      when 'option'
        f.puts "      <i>Options #{texte} (#{ects}&nbsp;crédits)</i>"

      when 'divers'
        f.puts "      <i>#{texte} (#{ects}&nbsp;crédits)</i>"

      when 'invisible'
        # On n'écrit rien

      else
        $stderr.puts "** Erreur dans semestre '#{ref_sem}' : type de groupe '#{type_grp}' non défini"
        f.puts "      <b>** TYPE DE GROUPE NON DÉFINI !!</b>"
    end

    legende = DocXml.get_text(elt_grp, 'legende')
    if legende != ""
      f.puts "        <br \>#{legende}"
    end

    f.puts ""
    f.puts "      <ul>"

    premier = true
    elt_grp.elements.each('matiere') do |elt_mat|
      gen_html_matiere(f, elt_mat, ref_sem)
    end

    f.puts "      </ul>"
  end


  # Génère le contenu des enseignements d'une matiere
  #
  def gen_html_matiere(f, elt_mat, ref_sem)

    ref_mat = DocXml.get_attr(elt_mat, 'ref')
    code    = DocXml.get_attr(elt_mat, 'code')
    titre   = DocXml.get_attr(elt_mat, 'titre')
    href    = DocXml.get_attr(elt_mat, 'href')
    texte   = DocXml.get_attr(elt_mat, 'texte')
    ects    = DocXml.get_attr(elt_mat, 'ects')

    ue = @base.x_ues.get_element('ue', 'id', ref_mat)
    if ue != nil
      if code  == "" then code  = DocXml.get_text(ue, 'code') ; end
      if titre == "" then titre = DocXml.get_text(ue, 'titre') ; end
      if href  == "" then href  = "ue-#{code}.html" ; end
      if ects  == "" then ects  = DocXml.get_text(ue, 'ects') ; end
    end

    if code == "" and titre == "" and texte == ""
      $stderr.puts "** Erreur dans semestre '#{ref_sem}' : matiere '#{ref_mat}' non définie"
      f.puts "        <li><b>** MATIERE NON DEFINIE !!</b></li>"
      return
    end

    f.print "        <li>"
    f.print "#{code}&nbsp;: " if code != ""
    f.print "<a href=\"#{href}\">" if href != ""
    f.print titre
    f.print "</a>" if href != ""
    f.print " #{texte} (#{ects} crédits)"
    f.puts "</li>"
  end


end  # Fin classe


