# encoding : UTF-8 
#
# gsf-responsables.rb - Génération de la liste des responsables
#
# Edouard.Thiel@lif.univ-mrs.fr - 22/11/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.


require './gsf-doc-xml'
require './gsf-base-docs'


class Responsables

  # Accesseurs
  #
  attr_accessor :base


  # Initialisation
  #
  def initialize(base)
    @base = base
  end


  #----------------------------------------------------------------------------

  # Génère la liste des responsables par ordre alphabétique
  #
  def gen_html_resps_alpha(f)

    if @base == nil || @base.x_cat == nil
      $stderr.puts "** Erreur: gen_html_resps_alpha: base XML non définie"
      return
    end

    # Création de la liste des enseignants
    liste = []
    @base.x_ens.elements.each('liste-enseignants/ens') do |elt_ens|
      ref_ens = DocXml.get_attr(elt_ens, 'id')
      liste << ref_ens
    end

    f.print <<-FINTEXTE
  <table class="table-resps">
  <tbody>
    <tr class="titre">
      <td>Nom</td>
      <td>Page web</td>
      <td>Adresse email</td>
      <td>Numéro de tél.</td>
    </tr>
    FINTEXTE

    # Parcours de la liste triée sur ref_ens (on triche un peu en ne
    # triant pas sur les noms).
    liste.sort.each do |ref_ens|
      gen_html_responsable_de_quoi(f, ref_ens)
    end

    f.puts "  </tbody>"    
    f.puts "  </table>"    
  end


  # Génère une ligne de la table des responsables
  #
  def gen_html_responsable_de_quoi(f, ref_ens)

    return if ref_ens == ""

    elt_ens = @base.x_ens.get_unique_element(
        "liste-enseignants/ens[@id='#{ref_ens}']")
    if elt_ens == nil
      $stderr.puts "** Erreur: enseignant #{ref_ens} non trouvé"
      return
    end

    nom = DocXml.get_attr(elt_ens, 'nom')
    if nom == ""
      $stderr.puts "** Erreur: nom vide pour enseignant #{ref_ens}"
      return
    end

    web = DocXml.get_attr(elt_ens, 'web')
    phone = DocXml.get_attr(elt_ens, 'phone')
    email = DocXml.get_attr(elt_ens, 'email')

    f.puts "    <tr id=\"#{ref_ens}\" class=\"coords\" >"
    f.puts "      <td>#{nom}</td>"

    if web != ""
         f.puts "      <td><a href=\"#{web}\">page perso</a></td>"
    else f.puts "      <td>-</td>"
    end

    if email != ""
         f.puts "      <td>#{email}</td>"
    else f.puts "      <td>-</td>"
    end

    if phone != ""
         f.puts "      <td>#{phone}</td>"
    else f.puts "      <td>-</td>"
    end

    f.puts "    </tr>"
    f.puts "    <tr class=\"liste\"><td colspan=\"4\"><ul>"

    gen_html_responsabilites_de_ens(f, ref_ens)

    f.puts "    </ul></td></tr>"
  end


  # Génère les responsabilités d'un enseignant
  #
  def gen_html_responsabilites_de_ens(f, ref_ens)

    return if ref_ens == ""

    @base.x_resp.elements.each(
        "liste-responsables/resp[@ref-ens='#{ref_ens}']") do |elt_resp|

      ref_page = DocXml.get_attr(elt_resp, 'ref-page')
      ref_ue = DocXml.get_attr(elt_resp, 'ref-ue')
      role = DocXml.get_attr(elt_resp, 'role')

      if ref_page != ""
        gen_html_responsabilites_dans_page(f, ref_page, role)
      elsif ref_ue != ""
        gen_html_responsabilites_dans_ue(f, ref_ue, role)
      else
        $stderr.puts "** Erreur: références de responsabilité vides pour #{ref_ens}"
      end

    end
  end


  # Génère les responsabilités d'un enseignant liées à une page
  #
  def gen_html_responsabilites_dans_page(f, ref_page, role)

    return if ref_page == ""

    elt_page = @base.x_pages.get_unique_element(
        "liste-pages/page[@id='#{ref_page}']")
    return if elt_page == nil

    surnom_page = DocXml.get_text(elt_page, 'surnom')
    if surnom_page == ""
      $stderr.puts "** Erreur: surnom vide pour la page #{ref_page}"
      return
    end
    dest_page = DocXml.get_attr(elt_page, 'dest')

    f.print "      <li>"
    f.print "<a href=\"#{dest_page}\">" if dest_page != ""
    f.print "#{surnom_page}"
    f.print "</a>" if dest_page != ""
    f.print " : #{role}" if role != ""
    f.puts "</li>"        
  end


  # Génère les responsabilités d'un enseignant liées à une UE
  #
  def gen_html_responsabilites_dans_ue(f, ref_ue, role)

    return if ref_ue == ""

    elt_ue = @base.x_ues.get_unique_element(
        "liste-ues/ue[@id='#{ref_ue}']")
    return if elt_ue == nil

    code_ue = DocXml.get_text(elt_ue, 'code')
    if code_ue == ""
      $stderr.puts "** Erreur: code vide pour l'UE #{ref_ue}"
      return
    end
    dest_ue = "ue-#{code_ue}.html"

    f.print "      <li>"
    f.print "<a href=\"#{dest_ue}\">" if dest_ue != ""
    f.print "UE #{code_ue}"
    f.print "</a>" if dest_ue != ""
    f.print " : #{role}" if role != ""
    f.puts "</li>"        
  end

end  # Fin classe


